CertificateHealthChecker class
Certificate health checker for monitoring certificate status
This class provides functionality to check the health and validity of SSL/TLS certificates for remote hosts.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkHost(
String host, int port) → Future< CertificateHealth> - Checks certificate health for a single host
-
checkMultipleHosts(
List< String> hosts, {int port = 443}) → Future<Map< String, CertificateHealth> > - Checks certificate health for multiple hosts
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited